package cz.muni.fi.pv181.java;

import java.io.FileNotFoundException;
import java.security.InvalidKeyException;
import java.security.NoSuchProviderException;


import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * 
 * @author pavel
 */
public class SHA1hash {

    private File file;
    private byte[] bytes = null;

    public SHA1hash(String pathToFile) {
        try {
            file = new File(pathToFile);
            InputStream is;

            long length = file.length();
            is = new FileInputStream(file);

            if (length > Integer.MAX_VALUE) {
                System.out.println("File is too large");
                System.exit(1);
            }

            bytes = new byte[(int) length];
            int offset = 0;
            int numRead = 0;

            while (offset < bytes.length && (numRead = is.read(bytes, offset, bytes.length - offset)) >= 0) {
                offset += numRead;
            }

            if (offset < bytes.length) {
                throw new IOException("Could not completely read file " + file.getName());
            }
            
            is.close();
        } catch (IOException ioe) {
            System.err.println(ioe.getMessage());
        }
    }

    public byte[] getHash() throws NoSuchProviderException {
        if (bytes == null) {
            throw new NullPointerException("bytes");
        }

        byte[] digest = null;

        MessageDigest hash;
        try {
            hash = MessageDigest.getInstance("SHA1");
            hash.reset();
            hash.update(bytes);
            digest = hash.digest();
        } catch (NoSuchAlgorithmException ex) {
            System.err.println(ex.getMessage());
        }
        
        return digest;
    }

    public static void main(String[] args) throws InvalidKeyException, NoSuchProviderException, FileNotFoundException, IOException {
        SHA1hash hash = new SHA1hash("\\boot.ini");
        StringBuilder hexString = new StringBuilder();
        byte[] digest = hash.getHash();
        for (int i = 0; i < digest.length; i++) {
            hexString.append(Integer.toHexString((digest[i] >>> 4) & 0x0F));
            hexString.append(Integer.toHexString(0x0F & digest[i]));
        }
        System.out.println("hash is " + hexString.toString());

    }
}
